@@ -255,6 +255,60 @@ fn query_sales() {
         .stdout(eq(expected_values));
 }
 
+#[test]
+fn query_decimals() {
+    // Setup table for test
+    let table_name = "QueryDecimals";
+    let conn = ENV.connect_with_connection_string(MSSQL).unwrap();
+    setup_empty_table(
+        &conn,
+        table_name,
+        &["NUMERIC(3,2) NOT NULL", "DECIMAL(3,2) NOT NULL"],
+    )
+    .unwrap();
+    let insert = format!(
+        "INSERT INTO {}
+        (a,b)
+        VALUES
+        (1.23, 1.23);",
+        table_name
+    );
+    conn.execute(&insert, ()).unwrap();
+
+    let expected_values = "{a: 1.23, b: 1.23}\n";
+
+    // A temporary directory, to be removed at the end of the test.
+    let out_dir = tempdir().unwrap();
+    // The name of the output parquet file we are going to write. Since it is in a temporary
+    // directory it will not outlive the end of the test.
+    let out_path = out_dir.path().join("out.par");
+    // We need to pass the output path as a string argument.
+    let out_str = out_path.to_str().expect("Temporary file path must be utf8");
+
+    let query = format!("SELECT a,b FROM {};", table_name);
+
+    Command::cargo_bin("odbc2parquet")
+        .unwrap()
+        .args(&[
+            "-vvvv",
+            "query",
+            out_str,
+            "--connection-string",
+            MSSQL,
+            &query,
+        ])
+        .assert()
+        .success();
+
+    // Use the parquet-read tool to verify the output. It can be installed with
+    // `cargo install parquet`.
+    let mut cmd = Command::new("parquet-read");
+    cmd.arg(out_str)
+        .assert()
+        .success()
+        .stdout(eq(expected_values));
+}
+
 #[test]
 fn query_all_the_types() {
     // Setup table for test
@@ -290,8 +344,8 @@ fn query_all_the_types() {
 
     let expected_values = "{\
         a: \"abcde\", \
-        b: 0.12, \
-        c: 0.12, \
+        b: 1.23, \
+        c: 1.23, \
         d: 42, \
         e: 42, \
         f: 1.23, \
@@ -2794,7 +2848,7 @@ pub fn setup_empty_table(
         "CREATE TABLE {} (id int IDENTITY(1,1),{});",
         table_name, cols
     );
-    conn.execute(&drop_table, ())?;
+    conn.execute(drop_table, ())?;
     conn.execute(&create_table, ())?;
     Ok(())
 }
